.. examples:

========
Examples
========

.. toctree::
    :maxdepth: 2

    flow_duration_curve_examples
    raster_hydrograph_examples
    streamflow_duration_hydrograph_examples
    cumulative_hydrograph_examples